termin-8 0.1.4

CHIP-8 emulator that runs in your terminal
termin-8-0.1.4 is not a library.

Termin-8

crates.io

Octo-compliant CHIP-8 emulator frontend that runs in your terminal.

It uses deca as the emulator backend, which supports CHIP-8, SUPER-CHIP (SCHIP) and XO-CHIP programs.

Installation

First, install Rust. Then, in your terminal:

cargo install termin-8

Usage

Termin-8 should work on Windows, Linux, and macOS. If it doesn't, please file an issue.

Download CHIP-8 ROMs from the internet, like the Chip8 Community Archive, or make your own in Octo.

Then run Termin-8 in your terminal:

termin-8 ROM

There are some command line options:

termin-8 --help

The hexadecimal CHIP-8 keypad is customarily mapped to the following keyboard keys:

1 2 3 4
q w e r
a s d f
z x c v

In addition, the arrow keys are bound to WASD.

You can also use some other keys:

  • i: interrupt execution, or continue execution after interrupt
  • o: single-step (while interrupted)
  • Esc: exit

Terminal requirements

Note that the terminal requirements vary depending on what kind of program you attempt to run.

Here's a table with the required terminal size and Unicode support needed to get features such as XO-CHIP color support, depending on the resolution of the CHIP-8 program you're running and the Unicode Block Elements support of your font:

Notes:

  • In your browser, the smallest pixel block (▘) probably looks square, but this might not be the case with your monospace terminal font.
  • Pretty much all fonts support the basic Unicode Block Elements in Unicode 1.0.0 which are used for the larger pixel blocks (█, ▀ and ▄), but support for the smallest blocks (like ▘) from Unicode 3.2 is much less common. Font families like DejaVu and Fira Code support them.

Limitations

  • Some games might not detect keypresses correctly. This is because detecting when a key is released is very hard in a terminal. Termin-8 does an approximation of keypress duration, but your OS's "key repeat" settings will influence how often it can poll for key presses.
  • Your terminal's bell will sound when there's sound, but XO-CHIP music is not supported (as a terminal can't play sound on its own).